#
# spec file for package python-pymediainfo
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           python-pymediainfo
Version:        6.1.0
Release:        bp156.1.1
Summary:        Python wrapper for the mediainfo library
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/sbraz/pymediainfo
Source0:        https://files.pythonhosted.org/packages/source/p/pymediainfo/pymediainfo-%{version}.tar.gz
Source99:       %{name}-rpmlintrc
BuildRequires:  %{python_module importlib-metadata if %python-version < 3.8}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  libmediainfo0
Requires:       libmediainfo0
%if 0%{?python_version_nodots} < 38
Requires:       python-importlib-metadata
%endif
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
This module is a Python wrapper for the mediainfo library.

%prep
%setup -q -n pymediainfo-%{version}
rm -rf pymediainfo.egg-info

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/pymediainfo
%{python_sitelib}/pymediainfo-%{version}-py%{python_version}.egg-info

%changelog
* Sun Oct 29 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.1.0
  * Add a buffer_size argument to parse()
  * Add Python 3.12 support
* Fri Aug 25 2023 Markéta Machová <mmachova@suse.com>
- (Build)Require python-importlib-metadata on Leap (boo#1214468)
* Mon Mar  6 2023 Matej Cepl <mcepl@suse.com>
- Don't use fdupes -s, it hurts.
* Fri Dec  2 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.0.1
  * doc: improve description of parse()'s full parameter
  version 6.0.0
  Breaking changes:
  * warning Drop support for Python 3.6
  New features:
  * Add support for Python 3.10 and 3.11
  * tests: start a local HTTP server instead of relying on
    GitHub, this means the test suite can now run without
    Internet access
  Bug fixes:
  * Fix doc build with recent sphinx versions
* Sun May  2 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 5.1.0
  * Improve errors when libmediainfo can't be loaded
* Sun Apr 11 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 5.0.4
  New features:
  * Remove setuptools runtime requirement by replacing
    pkg_resources with importlib.metadata
  * __version__ is now an empty string if the package is not
    installed
  Miscellaneous:
  * Use setuptools_scm programatically in Sphinx's configuration
    instead of calling setup.py --version
* Tue Nov 24 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 5.0.3
  * Fix TypeError when parsing certain files
* Fri Nov 20 2020 aloisio@gmx.com
- Update to version 5.0.2
  Breaking changes:
  * warning Drop support for Python 2.7, 3.4 and 3.5
  * MediaInfo.parse: remove the deprecated text parameter
  New features:
  * MediaInfo: add shortcuts to tracks by type: audio_tracks,
    video_tracks, etc.
* Sat Nov  7 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.3
  * MediaInfo.parse: add support for file-like objects
  * Improvements to documentation
  * Python 3.9 is now officially supported
* Thu Apr 30 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.2.1
  Bug fixes:
  * Fix version detection for Read the Docs documentation builds
  version 4.2
  New features:
  * Add a new output option to the parse method, this deprecates
    the old test option (#82)
  * Add support for os.PathLike objects (#72)
  Bug fixes:
  * Close and delete handle on errors to avoid memory leaks (#79)
  * Fix thread-safety that was broken since v4.1 (#76 and #83),
    document multi-threading limitations
  * Document Python 3.8 support
  * Show the correct pymediainfo version in documentation builds
* Wed Sep 18 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.1
  * Added an argument to pass custom options to the parse method
    (#71)
* Sat Sep 14 2019 Luigi Baldoni <aloisio@gmx.com>
- Fixed tests in Factory
* Mon Apr 22 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.0
  * Drop Python 2.6 compatibility
  * Allow pickling of Track instances (#68)
  * Remove xml attributes from Track and MediaInfo objects,
    populate the tracks attribute immediately (03f6242)
  * Implement __eq__ forTrack and MediaInfo objects
  * Add an option to obtain MediaInfo's text output (#66)
  * Add an option to return non-complete MediaInfo (#66)
  * Disable LegacyStreamDisplay explicitly by default, make it
    configurable (see 9aa65d8 for details)
  version 3.2.1:
  * Generate sdists on Linux instead of OSX (#67)
  version 3.2:
  * Publish wheels containing libmediainfo (#59, thanks to
    @bgermann)
  version 3.1:
  * Add an option to control parsing speed (#65)
  version 3.0:
  * Do not ignore exceptions when invalid XML is passed (#53)
  * Raise RuntimeError if parsing fails
  * Add an option to ignore UTF-8 encoding errors, fixes (#54)
  * Use proper XPath to detect track elements in XML (#55)
  * Fix handling of non-existent files
  * Fix tests with libmediainfo ≥ 18.08 (#58)
  * Try to load libmediainfo from the module folder
* Wed Sep 12 2018 aloisio@gmx.com
- Update to version 2.3.0
  * Add setuptools to install_requires (#50)
  * Add an option to extract cover_data for libmediainfo ≥ 18.03
    (#51)
  * Get version from setuptools_scm
* Sat Nov 11 2017 aloisio@gmx.com
- Update to version 2.2.0
  * Support MediaInfo v17.10
  * Make parse support non-standard library locations (#24)
  * Make parse support pathlib objects (#40)
  * Add PyPy and PyPy3 support
  * Run tests with pytest instead of nose
- Dropped python-pymediainfo-skip_URL_test.patch (skipping network
  test from the command line now)
* Fri Jul  7 2017 aloisio@gmx.com
- Initial package (2.1.9)
